==> drop_account-2.2.0.tar.gz: drop_account/lib/Listeners/UserReEnabledListener.php <==
<?php
/**
 * @copyright Copyright (c) 2021 Thomas Citharel <nextcloud@tcit.fr>
 *
 * @author Thomas Citharel <nextcloud@tcit.fr>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\DropAccount\Listeners;

use OCA\DropAccount\AppInfo\Application;
use OCA\DropAccount\BackgroundJob\DeleteAccountData;
use OCA\DropAccount\Service\MailerService;
use OCP\BackgroundJob\IJobList;
use OCP\EventDispatcher\Event;
use OCP\EventDispatcher\IEventListener;
use OCP\IConfig;
use OCP\User\Events\UserChangedEvent;
use Psr\Log\LoggerInterface;

/**
 * @template-implements IEventListener<Event|UserChangedEvent>
 */
class UserReEnabledListener implements IEventListener
{
	private IConfig $config;
	private IJobList $jobList;
	private MailerService $mailerService;
	private LoggerInterface $logger;

	public function __construct(IJobList $jobList, IConfig $config, MailerService $mailerService, LoggerInterface $logger)
	{
		$this->jobList = $jobList;
		$this->config = $config;
		$this->mailerService = $mailerService;
		$this->logger = $logger;
	}

	public function handle(Event $event): void
	{
		$this->logger->debug('Handle event in UserReEnabledListener', ['event' => $event]);
		if ($event instanceof UserChangedEvent) {
			$user = $event->getUser();
			$uid = $user->getUID();
			/** @var mixed $feature */
			$feature = $event->getFeature();
			/** @var mixed $oldValue */
			$oldValue = $event->getOldValue();
			/** @var mixed $value */
			$value = $event->getValue();

			// We only do things on status being enabled
			if ($feature === 'enabled' && $value === true && $oldValue === false) {
				$this->logger->info('Re-enabling an user', ['event' => $event]);
				// Clear dedicated job if we have one
				if ($this->jobList->has(DeleteAccountData::class, ['uid' => $uid])) {
					$this->jobList->remove(DeleteAccountData::class, ['uid' => $uid]);
				}
				if ($this->config->getUserValue($uid, Application::APP_NAME, 'markedForPurge') === 'yes') {
					try {
						$this->mailerService->sendReactivationEmail($user);
					} catch (\Exception $exception) {
						// Nothing to do, there can be issues with sending email, but we don't care
					}
				}
				// Always clear purge values anyway
				$this->config->deleteUserValue($uid, Application::APP_NAME, 'markedForPurge');
				$this->config->deleteUserValue($uid, Application::APP_NAME, 'purgeDate');
			}
		}
	}
}

==> drop_account-2.4.0.tar.gz: drop_account/lib/Listeners/UserReEnabledListener.php <==
<?php
/**
 * @copyright Copyright (c) 2021 Thomas Citharel <nextcloud@tcit.fr>
 *
 * @author Thomas Citharel <nextcloud@tcit.fr>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\DropAccount\Listeners;

use Exception;
use OCA\DropAccount\AppInfo\Application;
use OCA\DropAccount\BackgroundJob\DeleteAccountData;
use OCA\DropAccount\Service\ActivityService;
use OCA\DropAccount\Service\MailerService;
use OCP\BackgroundJob\IJobList;
use OCP\EventDispatcher\Event;
use OCP\EventDispatcher\IEventListener;
use OCP\IConfig;
use OCP\User\Events\UserChangedEvent;
use Psr\Log\LoggerInterface;

/**
 * @template-implements IEventListener<Event|UserChangedEvent>
 */
class UserReEnabledListener implements IEventListener {
	private IConfig $config;
	private IJobList $jobList;
	private MailerService $mailerService;
	private ActivityService $activityService;
	private LoggerInterface $logger;

	public function __construct(IJobList $jobList, IConfig $config, MailerService $mailerService, ActivityService $activityService, LoggerInterface $logger) {
		$this->jobList = $jobList;
		$this->config = $config;
		$this->mailerService = $mailerService;
		$this->activityService = $activityService;
		$this->logger = $logger;
	}

	public function handle(Event $event): void {
		$this->logger->debug('Handle event in UserReEnabledListener', ['event' => $event]);
		if ($event instanceof UserChangedEvent) {
			$user = $event->getUser();
			$uid = $user->getUID();
			/** @var mixed $feature */
			$feature = $event->getFeature();
			/** @var mixed $oldValue */
			$oldValue = $event->getOldValue();
			/** @var mixed $value */
			$value = $event->getValue();

			// We only do things on status being enabled
			if ($feature === 'enabled' && $value === true && $oldValue === false) {
				$this->logger->info('Re-enabling an user', ['event' => $event]);
				// Clear dedicated job if we have one
				if ($this->jobList->has(DeleteAccountData::class, ['uid' => $uid])) {
					$this->jobList->remove(DeleteAccountData::class, ['uid' => $uid]);
				}
				if ($this->config->getUserValue($uid, Application::APP_NAME, 'markedForPurge') === 'yes') {
					try {
						$this->mailerService->sendReactivationEmail($user);
						$this->activityService->createAdminActivities($user, ['subject' => 'account_re_enabled']);
						$this->activityService->sendActivities();
					} catch (Exception) {
						// Nothing to do, there can be issues with sending email, but we don't care
					}
				}
				// Always clear purge values anyway
				$this->config->deleteUserValue($uid, Application::APP_NAME, 'markedForPurge');
				$this->config->deleteUserValue($uid, Application::APP_NAME, 'purgeDate');
			}
		}
	}
}
